/// <reference types="node" />
import { PlatformAccessory, CharacteristicValue } from 'homebridge';
import { Socket } from 'dgram';
import { GreePlatform } from './platform';
import { HeaterCoolerToggleSwitch } from './HeaterCoolerToggleSwitch';
import { DeviceConfig, SwitchName } from './types';
/**
 * Platform Accessory
 * An instance of this class is created for each accessory your platform registers
 * Each accessory may expose multiple services of different service types.
 */
export declare class GreeAirConditioner {
    readonly platform: GreePlatform;
    readonly accessory: PlatformAccessory;
    readonly deviceConfig?: DeviceConfig | undefined;
    private HeaterCooler;
    private Fan?;
    private Info;
    private PowerSwitch?;
    private QuietModeSwitch?;
    private LightSwitch?;
    private PowerfulModeSwitch?;
    private VerticalSwing?;
    private HorizontalSwing?;
    private DryModeToggle?;
    private FanModeToggle?;
    private SleepModeToggle?;
    private xFanModeToggle?;
    private key;
    socket: Socket;
    private binded;
    private isPending;
    private updateTimer;
    private cols;
    private status;
    constructor(platform: GreePlatform, accessory: PlatformAccessory, deviceConfig?: DeviceConfig | undefined);
    getCharacteristic(key: any, callback: any): void;
    setCharacteristic(key: any, value: CharacteristicValue, callback: any): void;
    get power(): boolean;
    set power(value: boolean);
    get deviceActive(): 1 | 0;
    set deviceActive(value: number);
    get currentTemperature(): number;
    get currentState(): 1 | 2 | 3 | 0;
    get targetState(): 1 | 2 | 0;
    set targetState(value: number);
    get targetTemperature(): number;
    set targetTemperature(value: number);
    get units(): 1 | 0 | undefined;
    set units(value: number | undefined);
    get speed(): number;
    set speed(value: number);
    get light(): boolean;
    set light(value: boolean);
    get quietMode(): boolean;
    set quietMode(value: boolean);
    get powerfulMode(): boolean;
    set powerfulMode(value: boolean);
    get sleepMode(): boolean;
    set sleepMode(value: boolean);
    get xFan(): boolean;
    set xFan(value: boolean);
    get verticalSwing(): boolean;
    set verticalSwing(value: boolean);
    get horizontalSwing(): boolean;
    set horizontalSwing(value: boolean);
    get dryMode(): boolean;
    set dryMode(value: boolean);
    get fanMode(): boolean;
    set fanMode(value: boolean);
    sendMessage(message: any): void;
    handleMessage: (msg: any, rinfo: any) => void;
    sendBindRequest(): void;
    requestDeviceStatus(): void;
    sendCommand(commands: any): void;
    updateStatus(patch: any): void;
    afterBinded(): void;
    getMac(): any;
    getAddress(): any;
    getPort(): any;
    getName(): any;
    getCols(): string[];
    getDeviceLabel(): string;
    getConfig(key: any): any;
    cacheMode(key: any): void;
    getModeCache(key: any, clear?: boolean): any;
    initSwitch(name: SwitchName, displayName: string): HeaterCoolerToggleSwitch | undefined;
    getConfiguredName(name: string): string;
}
//# sourceMappingURL=platformAccessory.d.ts.map